@@ -25,7 +25,7 @@ class TestAiDriver():
         self.api_key = api_key
         self.run_id = str(uuid.uuid1())
         if server_url is None:
-            server_url = os.environ.get('TESTAI_FLUFFY_DRAGON_URL', 'https://fluffy-dragon.test.ai')
+            server_url = os.environ.get('TESTAI_FLUFFY_DRAGON_URL', 'https://sdk.test.ai')
         self.url = server_url
 
         window_size = self.driver.get_window_size()
